@@ -10,11 +10,13 @@
 # Copyright:
 #             (c) 2005 - 2009 Gunnar Wrobel
 #             (c) 2009        Sebastian Pipping
+#             (c) 2009        Christian Groschupp
 #             Distributed under the terms of the GNU General Public License v2
 #
 # Author(s):
 #             Gunnar Wrobel <wrobel@gentoo.org>
 #             Sebastian Pipping <sebastian@pipping.org>
+#             Christian Groschupp <christian@groschupp.org>
 #
 '''Main handler for overlays.'''
 
@@ -26,7 +28,8 @@ __version__ = "$Id: overlay.py 273 2006-12-30 15:54:50Z wrobel $"
 #
 #-------------------------------------------------------------------------------
 
-import sys, codecs, os, os.path, xml.dom.minidom
+import sys, codecs, os, os.path
+import xml.etree.ElementTree as ET # Python 2.5
 
 from   layman.overlays.bzr       import BzrOverlay
 from   layman.overlays.darcs     import DarcsOverlay
@@ -38,6 +41,7 @@ from   layman.overlays.rsync     import RsyncOverlay
 from   layman.overlays.tar       import TarOverlay
 
 from   layman.debug              import OUT
+from   layman.utils              import indent
 
 #===============================================================================
 #
@@ -45,14 +49,16 @@ from   layman.debug              import OUT
 #
 #-------------------------------------------------------------------------------
 
-OVERLAY_TYPES = {'git'       : GitOverlay,
-                 'cvs'       : CvsOverlay,
-                 'svn'       : SvnOverlay,
-                 'rsync'     : RsyncOverlay,
-                 'tar'       : TarOverlay,
-                 'bzr'       : BzrOverlay,
-                 'mercurial' : MercurialOverlay,
-                 'darcs'     : DarcsOverlay}
+OVERLAY_TYPES = dict((e.type_key, e) for e in (
+    GitOverlay,
+    CvsOverlay,
+    SvnOverlay,
+    RsyncOverlay,
+    TarOverlay,
+    BzrOverlay,
+    MercurialOverlay,
+    DarcsOverlay
+))
 
 #===============================================================================
 #
@@ -63,8 +69,9 @@ OVERLAY_TYPES = {'git'       : GitOverlay,
 class Overlays:
     ''' Handle a list of overlays.'''
 
-    def __init__(self, paths, ignore = 0, quiet = False):
+    def __init__(self, paths, config, ignore = 0, quiet = False):
 
+        self.config = config
         self.quiet = quiet
         self.paths = paths
         self.ignore = ignore
@@ -77,58 +84,60 @@ class Overlays:
             if os.path.exists(path):
                 self.read_file(path)
 
+    def __eq__(self, other):
+        for key in set(self.overlays.keys() + other.overlays.keys()):
+            if self.overlays[key] != other.overlays[key]:
+                return False
+        return True
+
+    def __ne__(self, other):
+        return not self.__eq__(other)
+
     def read_file(self, path):
         '''Read the overlay definition file.'''
 
         try:
-
-            document = open(path).read()
+            document = open(path, 'r').read()
 
         except Exception, error:
             raise IOError('Failed to read the overlay list at ("'
                           + path + '")!\nError was:\n' + str(error))
 
-
         self.read(document)
 
-    def read(self, document):
+    def read(self, text):
         '''
         Read an xml list of overlays.
 
         >>> here = os.path.dirname(os.path.realpath(__file__))
-
-        >>> a = Overlays([here + '/tests/testfiles/global-overlays.xml', ])
+        >>> config = {'svn_command': '/usr/bin/svn', 'rsync_command':'/usr/bin/rsync'}
+        >>> a = Overlays([here + '/tests/testfiles/global-overlays.xml', ], config)
         >>> a.overlays.keys()
         [u'wrobel', u'wrobel-stable']
 
-        >>> a.overlays['wrobel-stable'].data['&src']
+        >>> a.overlays['wrobel-stable'].src
         u'rsync://gunnarwrobel.de/wrobel-stable'
         '''
-        try:
-
-            document = xml.dom.minidom.parseString(document)
-
-        except Exception, error:
-            raise Exception('Failed to parse the overlay list!\nError was:\n'
-                            + str(error))
-
-        overlays = document.getElementsByTagName('overlay') + \
-                document.getElementsByTagName('repo')
+        document = ET.fromstring(text)
+        overlays = document.findall('overlay') + \
+                document.findall('repo')
 
         for overlay in overlays:
-
             OUT.debug('Parsing overlay entry', 8)
-            try:
-                element_to_scan = overlay.getElementsByTagName('source')[0]
-            except IndexError:
+            
+            _source = overlay.find('source')
+            if _source != None:
+                element_to_scan = _source
+            else:
                 element_to_scan = overlay
 
-            for index in range(0, element_to_scan.attributes.length):
-                attr = element_to_scan.attributes.item(index)
-                if attr.name == 'type':
-                    if attr.nodeValue in OVERLAY_TYPES.keys():
+            for attr_name in element_to_scan.attrib.keys():
+                if attr_name == 'type':
+                    overlay_type = element_to_scan.attrib['type']
+                    if overlay_type in OVERLAY_TYPES.keys():
                         try:
-                            ovl = OVERLAY_TYPES[attr.nodeValue](overlay,
+                            ovl = OVERLAY_TYPES[overlay_type](overlay,
+                                                                self.config,
                                                                 self.ignore,
                                                                 self.quiet)
                             self.overlays[ovl.name] = ovl
@@ -136,7 +145,8 @@ class Overlays:
                             OUT.warn(str(error), 3)
                     else:
                         raise Exception('Unknown overlay type "' +
-                                        attr.nodeValue + '"!')
+                                        overlay_type + '"!')
+                    break
 
     def write(self, path):
         '''
@@ -144,34 +154,29 @@ class Overlays:
 
         >>> write = os.tmpnam()
         >>> here = os.path.dirname(os.path.realpath(__file__))
-
-        >>> a = Overlays([here + '/tests/testfiles/global-overlays.xml', ])
-        >>> b = Overlays([write,])
+        >>> config = {'svn_command': '/usr/bin/svn', 'rsync_command':'/usr/bin/rsync'}
+        >>> a = Overlays([here + '/tests/testfiles/global-overlays.xml', ], config)
+        >>> b = Overlays([write,], dict())
         >>> b.overlays['wrobel-stable'] = a.overlays['wrobel-stable']
         >>> b.write(write)
-        >>> c = Overlays([write,])
+        >>> c = Overlays([write,], dict())
         >>> c.overlays.keys()
         [u'wrobel-stable']
 
         >>> os.unlink(write)
         '''
 
-        imp = xml.dom.minidom.getDOMImplementation()
-
-        doc = imp.createDocument('layman', 'repositories', None)
-
-        root =  doc.childNodes[0]
-
-        for name, overlay in self.overlays.items():
-
-            root.appendChild(overlay.to_minidom(doc))
-
+        xml = ET.Element('repositories', version="1.0")
+        xml[:] = [e.to_xml() for e in self.overlays.values()]
+        indent(xml)
+        tree = ET.ElementTree(xml)
         try:
-
-            out_file = codecs.open(path, 'w', 'utf-8')
-
-            doc.writexml(out_file, '', '  ', '\n')
-
+            f = open(path, 'w')
+            f.write("""\
+<?xml version="1.0" encoding="UTF-8"?>
+""")
+            tree.write(f, encoding='utf-8')
+            f.close()
         except Exception, error:
             raise Exception('Failed to write to local overlays file: '
                             + path + '\nError was:\n' + str(error))
@@ -181,8 +186,9 @@ class Overlays:
         Select an overlay from the list.
 
         >>> here = os.path.dirname(os.path.realpath(__file__))
-        >>> a = Overlays([here + '/tests/testfiles/global-overlays.xml', ])
-        >>> a.select('wrobel-stable').data['&src']
+        >>> config = {'svn_command': '/usr/bin/svn', 'rsync_command':'/usr/bin/rsync'}
+        >>> a = Overlays([here + '/tests/testfiles/global-overlays.xml', ], config)
+        >>> a.select('wrobel-stable').src
         u'rsync://gunnarwrobel.de/wrobel-stable'
         '''
         if overlay in self.overlays.keys():
@@ -193,7 +199,8 @@ class Overlays:
         List all overlays.
 
         >>> here = os.path.dirname(os.path.realpath(__file__))
-        >>> a = Overlays([here + '/tests/testfiles/global-overlays.xml', ])
+        >>> config = {'svn_command': '/usr/bin/svn', 'rsync_command':'/usr/bin/rsync'}
+        >>> a = Overlays([here + '/tests/testfiles/global-overlays.xml', ], config)
         >>> for i in a.list(True):
         ...     print i[0]
         wrobel
