@@ -25,8 +25,9 @@ __version__ = "$Id: tar.py 310 2007-04-09 16:30:40Z wrobel $"
 #-------------------------------------------------------------------------------
 
 import os, os.path, sys, urllib2, shutil
+import xml.etree.ElementTree as ET # Python 2.5
 
-from   layman.utils             import path
+from   layman.utils             import path, ensure_unicode
 from   layman.overlays.overlay  import Overlay
 
 #===============================================================================
@@ -50,6 +51,7 @@ class TarOverlay(Overlay):
     ...     self.subpath = 'layman-test'
     ...     self.format = 'bz2'
     ...     self.quiet = False
+    ...     self.config = {'tar_command':'/bin/tar'}
     >>> testdir = os.tmpnam()
     >>> os.mkdir(testdir)
     >>> a = DummyTar()
@@ -62,32 +64,70 @@ class TarOverlay(Overlay):
     '''
 
     type = 'Tar'
+    type_key = 'tar'
 
-    binary = u'/bin/tar'
+    def __init__(self, xml, config, ignore = 0, quiet = False):
 
-    def __init__(self, xml, ignore = 0, quiet = False):
+        Overlay.__init__(self, xml, config, ignore)
 
-        Overlay.__init__(self, xml, ignore)
+        # Handle attribute format of old layman-global.txt format
+        # See _set_source() for repositories.xml variant
+        if not self.format and 'format' in xml.attrib:
+            self.format = ensure_unicode(xml.attrib['format'])
 
-        if '&format' in self.data.keys():
-            self.format = self.data['&format']
-        else:
-            self.format = ''
-
-        if '&subpath' in self.data.keys():
-            self.subpath = self.data['&subpath']
+        _subpath = xml.find('subpath')
+        if _subpath != None:
+            self.subpath = ensure_unicode(_subpath.text.strip())
+        elif 'subpath' in xml.attrib:
+            self.subpath = ensure_unicode(xml.attrib['subpath'])
         else:
             self.subpath = ''
 
-        if '&category' in self.data.keys():
-            if self.subpath:
-                raise Exception('Cannot use "category" and "subpath" at the same'
-                                ' time!')
-
-            self.category = self.data['&category']
+        _category = xml.find('category')
+        if _category != None:
+            self.category = ensure_unicode(_category.text.strip())
+        elif 'category' in xml.attrib:
+            self.category = ensure_unicode(xml.attrib['category'])
         else:
             self.category = ''
 
+        if self.subpath and self.category:
+            raise Exception('Cannot use "category" and "subpath" at the same time!')
+
+    def __eq__(self, other):
+        res = super(TarOverlay, self).__eq__(other) \
+            and self.format == other.format \
+            and self.subpath == other.subpath \
+            and self.category == other.category
+        return res
+
+    def __ne__(self, other):
+        return not self.__eq__(other)
+
+    # overrider
+    def _set_source(self, source_elem):
+        # Handle attribute format of new repositories.xml format
+        if 'format' in source_elem.attrib:
+            self.format = ensure_unicode(source_elem.attrib['format'])
+        else:
+            self.format = ''
+        super(TarOverlay, self)._set_source(source_elem)
+
+    # overrider
+    def to_xml(self):
+        repo = super(TarOverlay, self).to_xml()
+        if self.format:
+            repo.find('source').attrib['format'] = self.format
+        if self.subpath:
+            _subpath = ET.Element('subpath')
+            _subpath.text = self.subpath
+            repo.append(_subpath)
+        if self.category:
+            _category = ET.Element('category')
+            _category.text = self.category
+            repo.append(_category)
+        return repo
+
     def add(self, base, quiet = False):
         '''Add overlay.'''
 
@@ -138,7 +178,7 @@ class TarOverlay(Overlay):
 
         os.makedirs(target)
 
-        result = self.cmd(self.binary + u' -v -x ' + opt + u' -f "' + pkg
+        result = self.cmd(self.command() + u' -v -x ' + opt + u' -f "' + pkg
                           + u'" -C "' + target + u'"')
 
         if self.subpath:
@@ -175,7 +215,7 @@ class TarOverlay(Overlay):
     def supported(self):
         '''Overlay type supported?'''
 
-        return Overlay.supported(self, [(self.binary,  'tar', 'app-arch/tar'), ])
+        return Overlay.supported(self, [(self.command(),  'tar', 'app-arch/tar'), ])
 
 if __name__ == '__main__':
     import doctest
